==> ReleaseV1.1.1.zip: winginterfacelibrary/src/LiveConsultation/AcceptLiveConsultationRequest.cs <==
using System.Collections.Generic;
using WingInterfaceLibrary.Enum.NotificationEnum;
using WingInterfaceLibrary.Request;

namespace WingInterfaceLibrary.LiveConsultation
{
    public class AcceptLiveConsultationRequest : TokenRequest
    {    
        /// <summary>
        /// 会诊编码
        /// </summary>
        /// <value>ConsultationDO_123456789</value>
        public string ConsultationCode { get; set; } = string.Empty;           
    }

    public class AcceptLiveConsultationResult
    {        
        /// <summary>
        /// 会诊编码
        /// </summary>
        /// <value>ConsultationDO_123456789</value>
        public string ConsultationCode { get; set; } = string.Empty;

        /// <summary>
        /// 用户编码
        /// </summary>
        /// <value>UserDO_123456789</value>
        public string UserCode { get; set; } = string.Empty;

        /// <summary>
        /// Room No. 
        /// </summary>
        /// <value></value>
        public int RoomNo { get; set; }

        /// <summary>
        /// Sdk app id
        /// </summary>
        /// <value></value>
        public int AppId { get; set; }

        /// <summary>
        /// User sign for rtc
        /// </summary>
        /// <value>123456</value>
        public string UserSign { get; set; } = string.Empty;

        public IList<LiveConsultationMember> UserLiveDatas { get; set; }

        public IList<LiveConsultationMember> DeviceLiveDatas { get; set; }
    }

    public class AcceptLiveConsultationNotification
    {
        /// <summary>
        /// 通知类型枚举 接受会诊的通知
        /// </summary>
        /// <value>26</value>
        public NotificationTypeEnum NotificationType => NotificationTypeEnum.AcceptLiveConsultationNotification;
        
        /// <summary>
        /// 会诊编码
        /// </summary>
        /// <value>ConsultationDO_123456789</value>
        public string ConsultationCode { get; set; } = string.Empty;
        
        /// <summary>
        /// The info of who accept the diagnosis metting invitation
        /// </summary>
        /// <value></value>
        public LiveConsultatioAccepterInfo Accepter {get;set;}
    }
}

==> ReleaseV1.1.2.zip: winginterfacelibrary/src/LiveConsultation/AcceptLiveConsultationRequest.cs <==
using System.Collections.Generic;
using WingInterfaceLibrary.Enum.NotificationEnum;
using WingInterfaceLibrary.Notifications;
using WingInterfaceLibrary.Request;

namespace WingInterfaceLibrary.LiveConsultation
{
    /// <summary>
    /// 接受会诊请求实体
    /// </summary>
    public class AcceptLiveConsultationRequest : TokenRequest
    {
        /// <summary>
        /// 会诊编码
        /// </summary>
        /// <value>ConsultationDO_123456789</value>
        public string ConsultationCode { get; set; } = string.Empty;
    }

    /// <summary>
    /// 接受会诊响应实体
    /// </summary>
    public class AcceptLiveConsultationResult
    {
        /// <summary>
        /// 会诊编码
        /// </summary>
        /// <value>ConsultationDO_123456789</value>
        public string ConsultationCode { get; set; } = string.Empty;

        /// <summary>
        /// 用户编码
        /// </summary>
        /// <value>UserDO_123456789</value>
        public string UserCode { get; set; } = string.Empty;

        /// <summary>
        /// Room No. 
        /// </summary>
        /// <value></value>
        public int RoomNo { get; set; }

        /// <summary>
        /// Sdk app id
        /// </summary>
        /// <value></value>
        public int AppId { get; set; }

        /// <summary>
        /// User sign for rtc
        /// </summary>
        /// <value>123456</value>
        public string UserSign { get; set; } = string.Empty;

        public IList<LiveConsultationMember> MemberLiveDatas { get; set; } = new List<LiveConsultationMember>();
    }
    /// <summary>
    /// 接受会诊通知
    /// </summary>
    /// <notificationDocFirstDirectory>通知服务</notificationDocFirstDirectory>
    /// <notificationDocSecondDirectory>客户端</notificationDocSecondDirectory>
    ///<notificationDocThirdDirectory>会诊</notificationDocThirdDirectory>
    public class AcceptLiveConsultationNotification : NotificationDTO
    {
        /// <summary>
        /// 通知类型枚举 接受会诊的通知
        /// </summary>
        /// <value>12</value>
        public override NotificationTypeEnum NotificationType => NotificationTypeEnum.AcceptLiveConsultationNotification;

        /// <summary>
        /// 会诊编码
        /// </summary>
        /// <value>ConsultationDO_123456789</value>
        public string ConsultationCode { get; set; } = string.Empty;

        /// <summary>
        /// 会诊接受方信息
        /// </summary>
        /// <value></value>
        public LiveConsultatioAccepterInfo Accepter { get; set; }
    }
}
